%% Andrea Ferrero and Martin Seneca %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Notes on the Underground: Monetary policy in resource-rich economy
%  Masterfile, March 2018
% 
% This script produces tables and figures in the paper. 
% 
% Inputs
%   - Dynare 4.3.1
%   - notesUndergroundJMCBData.xlsx
%   - ssfn.m (function to solve for steady state)
%   - notesUndergroundJMCBmploop.dyn
%   - notesUndergroundJMCBvarloop.dyn
% 
%
% Monetary policy regimes considered:
%    Loop#  Short           Description
%    ----   -----           -----------
%    1      Discretion      Optimal policy under discretion
%    2      Optimal         Optimal policy under timeless commitment
%    3      ICITRL          Inertial Taylor rule in CPI inflation and mainland output level
%    4      SDIT            Strict domestic inflation targeting
%    5      SCIT            Strict CPI inflation targeting
%    6      Peg             Strict exchange rate peg
%    7      ICITRG          Inertial Taylor rule in CPI inflation and mainland output growth
%    8      ICITRE          Inertial Taylor rule in CPI inflation and efficient output gap
%    9      IDITRE          Inertial Taylor rule in domestic inflation and efficient output gap
%    10     CITRG           Taylor rule in CPI inflation and mainland output growth
%    11     CITRL           Taylor rule in CPI inflation and mainland output level
%    12     CITRE           Taylor rule in CPI inflation and efficient output gap
%    13     OICITRL         Optimised inertial Taylor rule in CPI inflation and output levels
%    14     DITR            "Domestic inflation-based Taylor rule"
%    15     CITR            "CPI inflation-based Taylor rule"
%    16     DITRE           Taylor rule in domestic inflation and efficient output gap
%    17     OICITRG         Optimised inertial Taylor rule in CPI inflation and output growth
%    18     OICITRE         Optimised inertial Taylor rule in CPI inflation and output gap
%    19     OIDITRE         Optimised inertial Taylor rule in domestic inflation and output gap
%    20                     Currently like 21
%    21     SNGDPGT         Strict mainland nominal GDP growth targeting
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Initialisation
clear all %#ok<CLALL>
close all
clc
addpath('C:\DYNARE\4.3.1\matlab')

% Print figures to pdf
printPDF = false;


%% FIGURE 1: Real oil price (Brent) and aggregate demand from oil sector (Norway)

% Sample period
newdates = 1978.25:0.25:2018;

% Read quarterly oil price data
[qrprice,~] = xlsread('notesUndergroundJMCBData','BrentReal','A74:B233');%[qrprice,qrdate] = xlsread('Oilprice','RealQuarterly','A42:B225');

% Read aggregate demand data
[index] = xlsread('notesUndergroundJMCBData','Norway','H3:H158');
index(157:160,:)=NaN;

figure(1);

subplot(2,1,1)
yyaxis left
line1 = plot(newdates,qrprice,'b','LineWidth',1);%plot(qdate,qrprice,'r--','LineWidth',1);
ylabel('2017-USD','Color','k')
set(gca,...
     'FontName','Times','FontSize',8,'YColor','k','YLim',[0 200])
yyaxis right
line2 = plot(newdates,index(:,1),'r--','LineWidth',1);
set(gca,...
     'FontName','Times','FontSize',8,'YColor','k','XTick',[1978 1983 1988 1993 1998 2003 2008 2013 2018],'XLim',[1978 2018],...
       'YLim',[3.75/100 8.5/100])
 title('Real oil price (Brent) and aggregate demand from oil sector (Norway)')
hL = legend([line1,line2],{'Real oil price (left-hand scale)','Demand from oil sector per capital unit (right-hand scale)'},'Orientation','horizontal');
newPosition = [0.465 0.465 0.1 0.1];
newUnits = 'normalized';
set(hL,'Position',newPosition,'Orientation','Horizontal','Units',newUnits,'Box','off')

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',screenposition(3:4));

if printPDF
    print -dpdf -painters FIGURE1
end


%% ESTIMATE OIL PRICE PROCESS 

% Read oil price data
[price,~] = xlsread('notesUndergroundJMCBData','BrentReal','A74:B233');

% Transform and detrend
qrprice = log(price);
% [qrptrend,qrpcycle] = hpfilter(qrprice,Inf);
qrpcycle = qrprice - mean(qrprice);
qrptrend = mean(qrprice)*ones(length(qrprice),1);
qrpdep = qrpcycle(2:end);
qrpind = qrpcycle(1:size(qrprice,1)-1);

% Regression
[rho,confint,res] = regress(qrpdep,qrpind);
sigma = std(res);


%% CALCULATE STEADY STATE VARIABLES

% Set global variables
global g_alpha g_varphi g_rho g_ch_yh g_m_yh g_g_yh g_yo_y

% Set fixed parameters
g_alpha = 0.4;
g_varphi = 3;
g_rho = 0.01;

% Set calibration targets
g_ch_yh = 0.85;
g_m_yh = 0.15;
g_g_yh = 0;
g_yo_y = 0.20;

% Set starting values
x0 = [.5 .5 .5 .5 .5];

% Call function to get
%   x(1) = NE
%   x(2) = eta
%   x(3) = YF
%   x(4) = AH
%   x(5) = AO
[x,fval] = fsolve(@ssfn,x0);


%% COMPUTE EFFICIENT STEADY STATE TO CHECK CALIBRATION

% Load parameters and steady-state values
alpha = g_alpha;
varphi = g_varphi;
rho = g_rho;
eta = x(2);
YF = x(3);
AH = x(4);
AO = x(5);
RPOF = 1;

% Calculate steady state
C = YF;
CH = (1-alpha)*C;
CF = alpha*C;
NE = ((1/(AH*(1-alpha)))*((1-alpha)*YF+(1/(1-eta))*(eta*AO*RPOF)^(1/(1-eta))))^(-1/varphi)
N = NE;
YH = AH*N;
M = (eta*AO*RPOF)^(1/(1-eta));
G = YH-CH-M;
YO = AO*M^eta;
YOtilde = YO-M;
YHtilde = YH;
Y = YHtilde+YOtilde;

% Check ratios
ch_yh = CH/YH;
m_yh = M/YH;
g_yh = G/YH;
yo_y = YOtilde/Y;
yh_y = YHtilde/Y;

% Report ratios
{'NE' 'ch_yh' 'm_yh' 'g_yh' 'yo_y' 'yh_y'}
[NE ch_yh m_yh g_yh yo_y yh_y]


%% COMPUTE COMPOSITE PARAMETERS

% Set fixed parameters
beta = 0.9963;
epsilon = 6;
theta = 0.75;
kappa = (1-beta*theta)*(1-theta)/theta;

% Compute composite parameters
gammatau = ch_yh + m_yh/(1-eta);
lambdatau = ch_yh + m_yh/(1-eta)^2;
lambdax = kappa*(lambdatau/gammatau^2 + varphi)/epsilon;
xi = kappa*(1+varphi*gammatau)/gammatau;
rel_weight = lambdax/xi;
rel_lambdatau_gammatausq = lambdatau/gammatau^2;


%% FIGURE 2: SENSITIVITY OF THE POLICY TRADE-OFF

% Starting values
x0 = [.5 .5 .5 .5 .5];

% Set global variables
global g_alpha g_varphi g_rho g_ch_yh g_m_yh g_g_yh g_yo_y  %#ok<REDEF>
g_g_yh = 0;  
g_yo_y = 0.20; 

% Specify grid for sensitivity analysis for s_m
grid = 0.0:0.01:0.5;

% Solve for grid
for ii = 1:length(grid) 

g_m_yh = grid(ii);
g_ch_yh = 1 - g_g_yh - g_m_yh;

% Call function to get
%   x(1) = NE
%   x(2) = eta
%   x(3) = YF
%   x(4) = AH
%   x(5) = AO
[x,fval] = fsolve(@ssfn,x0);

eta = x(2);
theta = 0.75;
beta = 0.9963;
kappa = (1-beta*theta)*(1-theta)/theta;

A_eta(ii) = eta;
A_gammatau(ii) = CH/YH + M/YH/(1-eta);
A_lambdatau(ii) = CH/YH + M/YH/(1-eta)^2;
A_lambdax(ii) = kappa*(A_lambdatau(ii)/A_gammatau(ii)^2 + varphi)/epsilon;
A_xi(ii) = kappa*(1+varphi*A_gammatau(ii))/A_gammatau(ii);
A_rel_weight(ii) = A_lambdax(ii)/A_xi(ii);

end

% Plot figure
figure(2);

subplot(2,2,1)
plot(grid,A_eta,'b','LineWidth',1)
hold on;
plot(grid(16),A_eta(16),'r*')
set(gca,...
    'FontName','Times','FontSize',8)
xlabel('s_m')
title('Material share in oil sector (\eta)')
hold off

subplot(2,2,2)
plot(grid,A_rel_weight,'b','LineWidth',1)
hold
plot(grid(16),A_rel_weight(16),'r*')
set(gca,...
    'FontName','Times','FontSize',8)
xlabel('s_m')
title('Slope of targeting rule (\lambda_x/\xi)')
hold off

subplot(2,2,3)
plot(grid,A_lambdax,'b','LineWidth',1)
hold
plot(grid(16),A_lambdax(16),'r*')
set(gca,...
    'FontName','Times','FontSize',8)
xlabel('s_m')
title('Output weight in loss function (\lambda_x)')
hold off

subplot(2,2,4)
plot(grid,A_xi,'b','LineWidth',1)
hold
plot(grid(16),A_xi(16),'r*')
set(gca,...
    'FontName','Times','FontSize',8)
xlabel('s_m')
title('Slope of Phillips curve (\xi)')
hold off
set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
   'PaperPosition',[0 0 screenposition(3:4)],...
     'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters FIGURE2
end


%% FIGURE 3: IMPULSE RESPONSES

% Run dynare file with loops over policy regimes for (rho_O,sigma_O)=(0.95,10)
dynare notesUndergroundJMCBmploop.dyn

% Plot IRFs for selected monetary policy regimes

figure('Name','Impulse responses');
subplot(3,3,1)
plot(0:1:20,IRF_POF(2, :),'k-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
title('Oil price')
hold off

subplot(3,3,2)
plot(0:1:20,IRF_YO(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_YO(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_YO(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_YO(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
title('Oil production')
hold off

subplot(3,3,3)
plot(0:1:20,IRF_M(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_M(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_M(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_M(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
title('Oil materials')
hold off

subplot(3,3,4)
line1 = plot(0:1:20,IRF_YH(2, :),'b-','LineWidth',1);
set(gca,...
    'FontName','Times','FontSize',8)
hold
line2 = plot(0:1:20,IRF_YH(14, :),'r--','LineWidth',1);
line3 = plot(0:1:20,IRF_YH(15, :),'k-.','LineWidth',1);
line4 = plot(0:1:20,IRF_YH(6, :),':','Color',[0 .6 0],'LineWidth',1.75);
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Mainland output')
hold off

subplot(3,3,5)
plot(0:1:20,IRF_X(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_X(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_X(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_X(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Output gap')
hold off

subplot(3,3,6)
plot(0:1:20,IRF_PIH(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PIH(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_PIH(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PIH(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Domestic inflation')
hold off

subplot(3,3,7)
plot(0:1:20,IRF_PI(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PI(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_PI(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PI(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('CPI inflation')
hold off

subplot(3,3,8)
plot(0:1:20,IRF_S(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_S(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_S(15, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_S(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Real exchange rate')
hold off

subplot(3,3,9)
plot(0:1:20,IRF_I(2, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_I(14, :),'r--','LineWidth',1)
plot(0:1:20,IRF_I(15, :),'k-.','LineWidth',1)
plot(0:1:20,zeros(21),'k-')
plot(0:1:20,IRF_I(6, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)

set(gca,...
    'FontName','Times','FontSize',8)
title('Nominal interest rate')
hold off

hL = legend([line1,line2,line3,line4],{'Optimal','DITR','CITR','Peg'},'Orientation','horizontal');
newPosition = [0.465 0.001 0.1 0.1];
newUnits = 'normalized';
set(hL,'Position',newPosition,'Orientation','Horizontal','Units',newUnits,'Box','off')

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters FIGURE3
end

%% Compute welfare losses for different monetary policy regimes

% Run dynare file with loops over policy regimes for (rho_O,sigma_O)=(0.95,15)
dynare notesUndergroundJMCBvarloop.dyn

% Compute losses
LOSS = (VARPIH + lambdax.*VARX)';
REL_LOSS = LOSS/LOSS(2);
CONTR_LOSS = LOSS-ones(length(LOSS),1)*LOSS(2);

% Print losses
{'I   ', 'PIH ', 'PI  ', 'PIE ', 'YH  ','TAU ','X   ','DIFF','RLTV'}
[(16*VARI).^(1/2)' (16*VARPIH).^(1/2)' (16*VARPI).^(1/2)' VARPIE.^(1/2)' VARYH.^(1/2)' VARTAU.^(1/2)' VARX.^(1/2)' CONTR_LOSS REL_LOSS]

%% APPENDIX FIGURE 1

[datash,~] = xlsread('notesUndergroundJMCBData','InputShares');
[dataex,~] = xlsread('notesUndergroundJMCBData','Exports');

figure
subplot(2,2,1)
plot(datash(:,1),100*datash(:,32),'b-','LineWidth',1)
hold
plot(datash(:,1),100*datash(:,33),'r-o','LineWidth',1)
plot(datash(:,1),100*datash(:,34),'k-.','LineWidth',1)
plot(datash(:,1),100*datash(:,35),'k-x','Color',[0 .6 0],'LineWidth',1)
plot(datash(:,1),100*datash(:,36),'m--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
axis([1970 2014 0 30])
title('Value added in M&Q')
ylabel('Share of total GDP (%)')

subplot(2,2,2)
plot(dataex(:,1),dataex(:,2),'b-','LineWidth',1)
hold
plot(dataex(:,1),dataex(:,3),'r-o','LineWidth',1)
plot(dataex(:,1),dataex(:,4),'k-.','LineWidth',1)
plot(dataex(:,1),dataex(:,5),'k-x','Color',[0 .6 0],'LineWidth',1)
plot(dataex(:,1),dataex(:,6),'m--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
axis([1970 2014 0 85])
title('M&Q exports')
ylabel('Share of total exports (%)')

subplot(2,2,3)
plot(datash(:,1),100*datash(:,27),'b','LineWidth',1)
hold
plot(datash(:,1),100*datash(:,28),'r-o','LineWidth',1)
plot(datash(:,1),100*datash(:,29),'k-.','LineWidth',1)
plot(datash(:,1),100*datash(:,30),'k-x','Color',[0 .6 0],'LineWidth',1)
plot(datash(:,1),100*datash(:,31),'m--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
axis([1970 2014 0 14])
title('Investment in M&Q')
ylabel('Share of non-M&Q GDP (%)')

subplot(2,2,4)
line1 = plot(datash(:,1),100*datash(:,22),'b-','LineWidth',1);
hold
line2 = plot(datash(:,1),100*datash(:,23),'r-o','LineWidth',1);
line3 = plot(datash(:,1),100*datash(:,24),'k-.','LineWidth',1);
line4 = plot(datash(:,1),100*datash(:,25),'k-x','Color',[0 .6 0],'LineWidth',1);
line5 = plot(datash(:,1),100*datash(:,26),'m--','LineWidth',1);
set(gca,...
    'FontName','Times','FontSize',8)
axis([1970 2014 0 14])
title('Materials in M&Q')
ylabel('Share of non-M&Q GDP (%)')

hL = legend([line1,line2,line3,line4,line5],{'Norway','Chile','Australia','Mexico','Canada'},'Orientation','horizontal');
newPosition = [0.465 0.001 0.1 0.1];
newUnits = 'normalized';
set(hL,'Position',newPosition,'Orientation','Horizontal','Units',newUnits,'Box','off')

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',screenposition(3:4));

if printPDF
    print -dpdf -painters APPFIGURE 1
end

%% APPENDIX FIGURES 2-5

% Run dynare file with loops over policy regimes for (rho_O,sigma_O)=(0.95,10)
% dynare notesUndergroundJMCBmploop.dyn

% Appendix Figure 2
figure('Name','Mainland economy');
subplot(2,3,1)
plot(0:1:20,IRF_YH(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_YH(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_YH(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_YH(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Mainland production')
legend('CITRL','CITRG','CITRE','DITRE','Location','SouthEast')
legend('boxoff')
hold off

subplot(2,3,2)
plot(0:1:20,IRF_X(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_X(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_X(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_X(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Output gap')
hold off

subplot(2,3,3)
plot(0:1:20,IRF_PIH(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PIH(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PIH(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PIH(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Domestic inflation')
hold off

subplot(2,3,4)
plot(0:1:20,IRF_PI(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PI(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PI(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PI(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('CPI inflation')
hold off

subplot(2,3,5)
plot(0:1:20,IRF_S(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_S(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_S(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_S(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Real exchange rate')
hold off

subplot(2,3,6)
plot(0:1:20,IRF_I(11, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_I(10, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_I(12, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_I(16, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Nominal interest rate')
hold off

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters APPFIGURE2
end

% Appendix Figure 3

figure('Name','Mainland economy');
subplot(2,3,1)
plot(0:1:20,IRF_YH(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_YH(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_YH(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_YH(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Mainland production')
legend('ICITRL','ICITRG','ICITRE','IDITRE','Location','SouthEast')
legend('boxoff')
hold off

subplot(2,3,2)
plot(0:1:20,IRF_X(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_X(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_X(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_X(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Output gap')
hold off

subplot(2,3,3)
plot(0:1:20,IRF_PIH(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PIH(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PIH(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PIH(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Domestic inflation')
hold off

subplot(2,3,4)
plot(0:1:20,IRF_PI(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PI(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PI(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PI(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('CPI inflation')
hold off

subplot(2,3,5)
plot(0:1:20,IRF_S(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_S(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_S(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_S(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Real exchange rate')
hold off

subplot(2,3,6)
plot(0:1:20,IRF_I(3, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_I(7, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_I(8, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_I(9, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Nominal interest rate')
hold off

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters APPFIGURE3
end

% Appendix Figure 4

figure('Name','Mainland economy');
subplot(2,3,1)
plot(0:1:20,IRF_YH(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_YH(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_YH(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Mainland production')
legend('SDIT','SCIT','SNGDPGT','Location','SouthEast')
legend('boxoff')
hold off

subplot(2,3,2)
plot(0:1:20,IRF_X(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_X(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_X(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Output gap')
hold off

subplot(2,3,3)
plot(0:1:20,IRF_PIH(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PIH(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PIH(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Domestic inflation')
hold off

subplot(2,3,4)
plot(0:1:20,IRF_PI(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PI(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PI(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('CPI inflation')
hold off

subplot(2,3,5)
plot(0:1:20,IRF_S(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_S(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_S(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Real exchange rate')
hold off

subplot(2,3,6)
plot(0:1:20,IRF_I(4, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_I(5, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_I(21, :),'k-.','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Nominal interest rate')
hold off

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters APPFIGURE4
end

% Appendix Figure 5

figure('Name','Mainland economy');
subplot(2,3,1)
plot(0:1:20,IRF_YH(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_YH(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_YH(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_YH(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Mainland production')
legend('OICITRL','OICITRG','OICITRE','OIDITRE','Location','SouthEast')
legend('boxoff')
hold off

subplot(2,3,2)
plot(0:1:20,IRF_X(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_X(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_X(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_X(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Output gap')
hold off

subplot(2,3,3)
plot(0:1:20,IRF_PIH(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PIH(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PIH(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PIH(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Domestic inflation')
hold off

subplot(2,3,4)
plot(0:1:20,IRF_PI(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_PI(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_PI(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_PI(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('CPI inflation')
hold off

subplot(2,3,5)
plot(0:1:20,IRF_S(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_S(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_S(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_S(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
set(gca,...
    'FontName','Times','FontSize',8)
title('Real exchange rate')
hold off

subplot(2,3,6)
plot(0:1:20,IRF_I(13, :),'b-','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
hold
plot(0:1:20,IRF_I(17, :),'r--','LineWidth',1)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,IRF_I(18, :),'k-.','LineWidth',1)
plot(0:1:20,IRF_I(19, :),':','Color',[0 .6 0],'LineWidth',1.75)
set(gca,...
    'FontName','Times','FontSize',8)
plot(0:1:20,zeros(21),'k-')
title('Nominal interest rate')
hold off

set(gcf,'Units','centimeters');
screenposition = get(gcf,'Position');
set(gcf,...
    'PaperPosition',[0 0 screenposition(3:4)],...
    'PaperSize',[screenposition(3:4)]);

if printPDF
    print -dpdf -painters APPFIGURE5
end